import { LogIn } from "./components/LogIn/LogIn";
import { Navigate, Route, RouteProps, Routes, useNavigate, useParams } from "react-router";
import { SignUp } from "./components/SignUp/SignUp";
import { CreateAirline } from "./components/CreateAirline/CreateAirline";
import { Home } from "./components/Home/Home";
import { CreateFlight } from "./components/CreateFlight/CreateFlight";
import { Button } from "antd";
import useAuth, { AuthProvider } from "./useAuth";
import { EditFlight } from "./components/CreateFlight/EditFlight/EditFlight";
import LandingPage from "./components/Landing/Landing";

function Router() {
    const { user, logout, isAirline, isAdmin } = useAuth();
    const navigate = useNavigate()

    return (
        <div className="App">
            <Routes>
                <Route path="/login" element={!user ? <LogIn /> : <Navigate to="/flights" />} />
                <Route path="/signup" element={<SignUp />} />
                <Route path="/create-airline" element={
                    !isAdmin ? (!user ? <Navigate to="/login" state={"/create-airline"} /> : <Navigate to="/flights" />) : <CreateAirline />
                } />
                <Route path="/flights" element={<Home />} />
                <Route path="/create-flight" element={
                    !isAirline ? (!user ? <Navigate to="/login" state={"/create-flight"} /> : <Navigate to="/flights" />) : <CreateFlight />
                } />
                <Route path="/edit-flight/:id" element={<EditFlightComponent />} />
                <Route path="/" element={<LandingPage />} />
                <Route path="*" element={<Navigate to="/" />} />
            </Routes>
            {window.location.pathname != '/' &&
                <div className="LogoutButton">
                    {!!!localStorage.getItem("token") ?
                        <Button
                            onClick={() => navigate("/login")}
                        >
                            Login
                        </Button>
                        :
                        <Button
                            onClick={logout}
                        >
                            Logout
                        </Button>
                    }
                </div>
            }
        </div>
    );
}

const EditFlightComponent = () => {
    const { isAirline, isAdmin, user } = useAuth();
    const params = useParams();

    if (!isAirline && !isAdmin) {
        if (!user) {
            return <Navigate to="/login" state={{ intendedPath: `/edit-flight/${params.id}` }} />;
        } else {
            return <Navigate to="/flights" />;
        }
    } else {
        return <EditFlight />;
    }
};

function App() {
    return (
        <AuthProvider>
            <Router />
        </AuthProvider>
    );
}

export default App;
