import { useCallback, useEffect } from "react";
import { useState } from "react";
import { Flight } from "../Types";
import { fetchFlights } from "../Api";

export const useFetchFlights = (page: number | null, search: string | null) => {
    const [isLoading, setIsLoading] = useState(false);
    const [error, setError] = useState<string | null>(null);
    const [flights, setFlights] = useState<Flight[]>([]);
    const [count, setCount] = useState<number>(0);

    const fetchData = useCallback(async () => {
        setError(null);
        setIsLoading(true)

        fetchFlights(page, search)
            .then((data) => {
                setCount(data.count)
                setFlights(data.flights);
            })
            .catch((error) => {
                if (error.response.status == 404) {
                    setCount(0)
                    setFlights([])
                }
            })
            .finally(() => setIsLoading(false))
    }, [page, search]);

    useEffect(() => {
        fetchData()
    }, [fetchData]);

    return { flights, count, isLoading, error, fetchData };
};
