#!/bin/bash -e

printModule() {
    section_name_length=${#1}
    separator_length=$((80 - ${section_name_length} - 2))
    mid_separator="$(printf "%$((${separator_length} / 2))s" "" | tr ' ' '|')"
    separator=$(printf "%80s" "" | tr ' ' '|')
    printf "\n${separator}\n"
    printf "${mid_separator} $1 ${mid_separator}"
    ((separator_length % 2 == 0)) || printf "|"
    printf "\n${separator}\n\n"
}

if [ "${TEST_TARGET:-}" = "INTEGRATION" ]; then
    /usr/src/app/.venv/bin/gunicorn src.api.main:app --worker-class uvicorn.workers.UvicornWorker --bind=0.0.0.0:5002
else
    printModule "TESTS"
    python -m pytest "src/tests" --junitxml=report.xml
    python -m pytest "src/tests" -p no:warnings --cov="src" --cov-report xml

    printModule "LINTING"
    flake8 src --extend-ignore E221 --extend-ignore E501
    black src --check
    isort . --src-path src --check --profile black

    printModule "SECURITY SCAN"
    bandit -c .bandit.yml -r .
fi
