import random

import pytest

from src.api.db import Base, SessionLocal, engine
from src.api.models.subscription import Subscription

session = SessionLocal()
base = Base


@pytest.fixture(scope="module")
def test_database():
    base.metadata.drop_all(bind=engine)
    base.metadata.create_all(bind=engine)
    yield session
    session.close()
    base.metadata.drop_all(bind=engine)


@pytest.fixture(scope="module")
def create_subscription():
    def create_subscription(subscription: Subscription):
        db_subscription = Subscription(
            user_id=subscription.user_id,
            flight_id=subscription.flight_id,
        )
        session.add(db_subscription)
        session.commit()
        session.refresh(db_subscription)
        return db_subscription

    return create_subscription


@pytest.fixture(scope="module")
def get_subscription():
    def get_subscription(user_id: int, flight_id: int):
        return (
            session.query(Subscription)
            .filter(
                Subscription.user_id == user_id, Subscription.flight_id == flight_id
            )
            .first()
        )

    return get_subscription


@pytest.fixture(scope="module")
def create_subscription_on_database(test_database, create_subscription):
    test_database.query(Subscription).delete()
    db_subscriptions = []
    for subscription in subscriptions:
        db_subscriptions.append(create_subscription(subscription))
    return db_subscriptions


@pytest.fixture(scope="module")
def subscription_to_create():
    return random.choice(subscriptions)


subscriptions = [
    Subscription(user_id=1, flight_id=1),
    Subscription(user_id=1, flight_id=2),
    Subscription(user_id=1, flight_id=3),
]
