from fastapi.testclient import TestClient

import src.api.cruds.subscription
from src.api.main import app

client = TestClient(app)


mocked_subscription = {"user_id": 1, "flight_id": 1}


def test_not_found_subscription(monkeypatch):
    def mock_get_subscription(db, user_id: int, flight_id: int):
        return None

    monkeypatch.setattr(
        src.api.cruds.subscription, "get_subscription", mock_get_subscription
    )
    resp = client.get("/subscriptions", params={"user_id": 3, "flight_id": 1})
    assert resp.status_code == 404


def test_successful_get_subscription(monkeypatch):
    def mock_get_subscription(db, user_id: int, flight_id: int):
        return mocked_subscription

    monkeypatch.setattr(
        src.api.cruds.subscription, "get_subscription", mock_get_subscription
    )
    response = client.get("/subscriptions?user_id=1&flight_id=1")
    assert response.status_code == 200
    assert response.json() == mocked_subscription
